.. SPDX-FileCopyrightText: 2021 Daniel Laidig <laidig@control.tu-berlin.de>
..
.. SPDX-License-Identifier: MIT

csgimu dummy repo
=================

|tests| |build| |docs| |version| |python| |format| |license| |downloads|

This is a dummy repo for testing. Real code coming soon.


.. |tests| image:: https://img.shields.io/github/workflow/status/dlaidig/csgimu/Tests?label=tests
    :target: https://github.com/dlaidig/csgimu/actions?query=workflow%3ATests
.. |build| image:: https://img.shields.io/github/workflow/status/dlaidig/csgimu/Build
    :target: https://github.com/dlaidig/csgimu/actions?query=workflow%3ABuild
.. |docs| image:: https://img.shields.io/readthedocs/csgimu
    :target: https://csgimu.readthedocs.io/
.. |version| image:: https://img.shields.io/pypi/v/csgimu
    :target: https://pypi.org/project/csgimu/
.. |python| image:: https://img.shields.io/pypi/pyversions/csgimu
    :target: https://pypi.org/project/csgimu/
.. |format| image:: https://img.shields.io/pypi/format/csgimu
    :target: https://pypi.org/project/csgimu/
.. |license| image:: https://img.shields.io/pypi/l/csgimu
    :target: https://github.com/dlaidig/csgimu/blob/main/LICENSES/MIT.txt
.. |downloads| image:: https://img.shields.io/pypi/dm/csgimu
    :target: https://pypi.org/project/csgimu/
